# SegView

visualise the 3D segmentation result

## Install

1. The most convenient way to install segview would be: `pip install segview` in your terminal
2. Alternatively, you could go to the folder of segview and execute: `python setup.py install`
3. Or, just include the file `segview.py` in your project directory.

## Use

### Segment result in 3D

### Segment result and raw image in 2D

### Locate result and raw image in 3D

### Locate result and raw image in 2D
